import preactLogo from '../../assets/preact.svg';
import viteLogo from '/vite.svg'
import { useEffect, useState } from "preact/hooks";
import { DefaultLayout } from '../../layouts/';
import { SeparatorWithAnchor } from '../../components';
import data from '../../datas/home.json';
import news from '../../datas/recent_news_event.json';
import popular from '../../datas/popular.json';
import critics_users_pick from '../../datas/critics_users_best_pick.json';
import popular_user_review from '../../datas/popular_user_reviews.json';
import './style.css';

type NewPlaces = {
  id: Number,
  name: string,
  thumbnail: string,
  location: string,
  critic_rating: Number,
  critic_voters: Number,
  user_rating: Number,
  user_voters: Number
}

type News = {
  header: string,
  thumbnail: string,
  link: string,
  comments_count: Number
  likes_count: Number
}

function Home() {
  const [count, setCount] = useState(0)

  const getUrl = async () => {

  }

  useEffect(() => {
    getUrl();
  }, [])

  return (
    <DefaultLayout>
      <div className="content main-content mt-3">

        {/* RECENTLY ADDED SECTION */}
        <section about={"Recently added places"} className={'mt-3'}>
          <SeparatorWithAnchor pageLink='#' pageName='recently added' secondLink='#' />
          {data.new_places.map((x: NewPlaces) => (
            <div className={"recently-added-section-card"}>
              {/* <p>{x.id}</p> */}
              <div style={{ width: 200, height: 200, overflow: 'hidden', borderRadius: 7 }}>
                <img alt={x.name} src={x.thumbnail} style={{ width: '100%', height: '100%' }} />
              </div>
              <div style={{ textAlign: 'left', borderBottomWidth: 1 }}>
                <p>{x.name}</p>
                <p>{x.location}</p>
              </div>
              <div className={"flex flex-row"}>
                <div>
                  <p>{x.critic_rating}</p>
                  <div style={{ height: 4, width: 40, backgroundColor: "#72767d" }}>
                    <div style={{ height: 4, width: `${x.critic_rating}%`, backgroundColor: 'green' }} />
                  </div>
                </div>
                <p>Critic Score ({x.critic_voters})</p>
              </div>
              <div className={"flex flex-row"}>
                <div>
                  <p>{x.user_rating}</p>
                  <div style={{ height: 4, width: 40, backgroundColor: "#72767d" }}>
                    <div style={{ height: 4, width: `${x.user_rating}%`, backgroundColor: 'green' }} />
                  </div>
                </div>
                <p>User score ({x.user_voters})</p>
              </div>
            </div>
          ))}
        </section>
        {/* END RECENTLY ADDED SECTION */}

        {/* START RECENT NEWS / EVENT SECTION */}
        {/* USE OPEN GRAPH PARSER TO READ OG DATA FROM HTML */}
        {/* https://github.com/dyatlov/go-opengraph */}
        <section className={"mt-10"}>
          <SeparatorWithAnchor pageLink='#' pageName='Recent News / Event' secondLink='#' />
          <div className={"mt-5"}>
            {news.data.map((x: News) => (
              <div style={{ display: 'inline-block', width: '33.3%', padding: '0 1% 15px', verticalAlign: 'top' }}>
                <div style={{ height: 250, overflow: 'hidden', borderRadius: 7 }}>
                  <img src={x.thumbnail} style={{ width: "100%", height: '100%', objectFit: 'cover', objectPosition: 'top' }} />
                </div>
                <a target="_blank" href={x.link}>{x.link.split("/")[2].replace(/www\./, '')}</a>
                <p>{x.header}</p>
                <div className={"flex flex-row"}>
                  <svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 -960 960 960" width="24"><path d="m480-120-58-52q-101-91-167-157T150-447.5Q111-500 95.5-544T80-634q0-94 63-157t157-63q52 0 99 22t81 62q34-40 81-62t99-22q94 0 157 63t63 157q0 46-15.5 90T810-447.5Q771-395 705-329T538-172l-58 52Zm0-108q96-86 158-147.5t98-107q36-45.5 50-81t14-70.5q0-60-40-100t-100-40q-47 0-87 26.5T518-680h-76q-15-41-55-67.5T300-774q-60 0-100 40t-40 100q0 35 14 70.5t50 81q36 45.5 98 107T480-228Zm0-273Z" /></svg>
                  <p>{x.likes_count}</p>
                  <svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 -960 960 960" width="24"><path d="M880-80 720-240H160q-33 0-56.5-23.5T80-320v-480q0-33 23.5-56.5T160-880h640q33 0 56.5 23.5T880-800v720ZM160-320v-480 480Zm594 0 46 45v-525H160v480h594Z" /></svg>
                  <p>{x.comments_count}</p>
                </div>
              </div>
            ))
            }
          </div>
        </section>
        {/* END RECENT NEWS / EVENT SECTION */}


        {/* START LOCATION CRITICS BEST AND USERS BEST SECTION */}
        <section className={"mt-10"}>
          <div class={"grid grid-cols-4 gap-12"}>
            <div className={'col-span-2 mr-5'}>
              <SeparatorWithAnchor pageLink='#' pageName={"Trending Now"} secondLink='#' />
              <div className={'grid grid-cols-3'}>
                {popular.data.map((x) => (
                  <div className={"m-2"}>
                    <div style={{ overflow: 'hidden', borderRadius: 7 }}>
                      <img src={x.thumbnail} style={{ height: 200, width: '100%' }} />
                    </div>
                    <p>{x.name}</p>
                    <p>{x.location}</p>
                  </div>
                ))}
              </div>
            </div>
            <div>
              <SeparatorWithAnchor pageLink='#' pageName={"Critic's Best"} />
              {critics_users_pick.critics.map((x) => (
                <div className={"mt-1"}>
                  <div style={{ width: 72, height: 72, float: 'left' }}>
                    <img src={x.thumbnail} style={{ height: '100%', width: '100%', }} />
                  </div>
                  <p>{x.name}</p>
                  <p>{x.location}</p>
                  <div style={{ display: 'inline-block' }}>
                    <p>{x.critic_rating} ({x.critic_voters})</p>
                    <div style={{ height: 4, width: 40, backgroundColor: "#72767d" }}>
                      <div style={{ height: 4, width: `${x.critic_rating}%`, backgroundColor: 'green' }} />
                    </div>
                  </div>
                </div>
              ))
              }
            </div>
            <div>
              <SeparatorWithAnchor pageLink='#' pageName={"User's Best"} />
              {critics_users_pick.users.map((x) => (
                <div className={"mt-1"}>
                  <div style={{ width: 72, height: 72, float: 'left' }}>
                    <img src={x.thumbnail} style={{ height: '100%', width: '100%', }} />
                  </div>
                  <p>{x.name}</p>
                  <p>{x.location}</p>
                  <div style={{ display: 'inline-block' }}>
                    <p>{x.user_rating} ({x.user_rating})</p>
                    <div style={{ height: 4, width: 40, backgroundColor: "#72767d" }}>
                      <div style={{ height: 4, width: `${x.user_rating}%`, backgroundColor: 'green' }} />
                    </div>
                  </div>
                </div>
              ))
              }
            </div>
          </div>
        </section>
        {/* LOCATION CRITICS BEST AND USERS BEST SECTION  */}

        <section className={"mt-10"}>
          <SeparatorWithAnchor pageLink='#' pageName={"Popular user reviews"} secondLink='#' />
          <div>
            {popular_user_review.data.map((x) => (
              <div style={{ display: 'inline-block', width: '33.3%', padding: '10px 2% 20px', verticalAlign: 'top', boxSizing: 'border-box' }}>
                <div style={{ float: 'left', width: 120, margin: '0 12px 10px 0' }}>
                  <img src={x.thumbnail} style={{ width: '100%' }} />
                </div>
                <p style={{ whiteSpace: 'nowrap' }} className={"text-sm"}>{x.place_name}</p>
                <p className={'text-sm'}>{x.location}</p>
                <p className={'text-sm'}>{x.username}</p>
                <div style={{ display: 'inline-block', overflow: 'hidden', verticalAlign: 'middle' }}>
                  <p>{x.rating}</p>
                  <div style={{ height: 4, width: 40, backgroundColor: "#72767d" }}>
                    <div style={{ height: 4, width: `${x.rating}%`, backgroundColor: 'green' }} />
                  </div>
                </div>
                <div  style={{ clear: 'both'}} className={'mb-3'}/>
                <div>
                  <p>{x.message}</p>
                </div>
              </div>
            ))

            }
          </div>
        </section>

        <div className="flex flex-row">
          <a href="https://vitejs.dev" target="_blank">
            <img src={viteLogo} class="logo" alt="Vite logo" />
          </a>
          <a href="https://preactjs.com" target="_blank">
            <img src={preactLogo} class="logo preact" alt="Preact logo" />
          </a>
        </div>
        <h1>Vite + Preact</h1>
        <div class="card">
          <button onClick={() => setCount((count) => count + 1)}>
            count is {count}
          </button>
          <p>
            Edit <code>src/app.tsx</code> and save to test HMR
          </p>
        </div>
        <p class="read-the-docs">
          Click on the Vite and Preact logos to learn more
        </p>
        <h1 className="text-3xl font-bold underline text-prime" >
          Hello world!
        </h1>
      </div>
    </DefaultLayout>

  )
}

export default Home;